@@ -12,10 +12,10 @@ test_vim() {
 		# Can only link with cpython
 		return 0
 	fi
-	if ! which "$POWERLINE_VIM_EXE" ; then
+	if ! command -v "$POWERLINE_VIM_EXE" ; then
 		return 0
 	fi
-	ln -sf "$(which "${POWERLINE_VIM_EXE}")" "$TEST_ROOT/path/vim"
+	ln -sf "$(command -v "${POWERLINE_VIM_EXE}")" "$TEST_ROOT/path/vim"
 	f="$ROOT/tests/test_in_vterm/test_vim.py"
 	if ! "${PYTHON}" "$f" ; then
 		local test_name="$(LANG=C "$POWERLINE_VIM_EXE" --cmd 'echo version' --cmd qa 2>&1 | tail -n2)"
